@@ -31,3 +31,13 @@ def wait(host:str, wait_time:int=60) -> None:
   from time import sleep
   while system(f'ping -c 1 {host}'): pass
   sleep(wait_time)
+
+def path_break(path:str) -> tuple[str,str,str]:
+  '''return folder, filname, ext'''
+  path = path.split('/')
+  folder = '/'.join(path[:-1])
+  filename = path[-1].split('.')
+  len_ = len(filename)
+  if len_ == 1: return folder, filename[0], ''
+  elif len_ == 2: return folder, filename[0], filename[-1]
+  else: return folder, '.'.join(filename[:-1]), filename[-1]
\ No newline at end of file
